import { BlockPermutation, EntityDamageCause, EquipmentSlot, system } from "@minecraft/server";
import { afterEvents, beforeEvents } from "../libraries/utils";
import WoodConvertions from "../libraries/wood_convertions";
import { DamageItem } from "../modules/Durability";
afterEvents.playerBreakBlock.subscribe(({ player }) => DamageItem(player, EquipmentSlot.Mainhand));
const cooldown = new Map();
beforeEvents.itemUseOn.subscribe(({ source: player, itemStack: item, block }) => {
    const pos = JSON.stringify(block.location);
    if (!item.typeId.startsWith('true_ep:') || cooldown.has(pos))
        return;
    cooldown.set(pos, system.runTimeout(() => cooldown.delete(pos), 5));
    const id = block.typeId;
    const tags = block.getTags();
    system.run(() => {
        let next = block.permutation;
        let sound = '';
        switch (item.typeId.split(':')[1]) {
            case 'emerald_hoe': {
                if (!tags.includes('grass') && !id.includes('dirt'))
                    return;
                sound = 'step.gravel';
                next = BlockPermutation.resolve('minecraft:farmland');
                break;
            }
            case 'emerald_axe': {
                const state = WoodConvertions[id];
                if (!state)
                    return;
                sound = 'use.wood';
                next = BlockPermutation.resolve(state);
                break;
            }
            case 'emerald_shovel': {
                if (id.match('minecraft:(farmland|grass_path)') || (!tags.includes('dirt') && !tags.includes('grass')))
                    return;
                sound = 'step.grass';
                next = BlockPermutation.resolve('minecraft:grass_path');
                break;
            }
            default: return;
        }
        block.setPermutation(next);
        player.dimension.playSound(sound, block.location);
        DamageItem(player, EquipmentSlot.Mainhand);
    });
});
afterEvents.entityHurt.subscribe(({ damageSource: { cause, damagingEntity: player } }) => {
    if (!player?.isPlayer() || cause !== EntityDamageCause.entityAttack)
        return;
    DamageItem(player, EquipmentSlot.Mainhand);
});
