import { BlockPermutation, system } from "@minecraft/server";
import { inAnyRadius } from "../../libraries/utils";
const timers = new Map();
const blacklist = ["minecraft:item", "pa:dummy_soul", "minecraft:arrow"];
export default {
    id: "wb:warden",
    Head: {
        lore: "§r§9+1 Soul Sensor",
        effect: {
            id: "water_breathing",
            amplifier: 0,
            duration: 3
        },
        func: (player) => {
            const { dimension } = player;
            if (!player.isSneaking || timers.has(player.id))
                return;
            if (!timers.has(player.id))
                timers.set(player.id, 0);
            const tracker = new Map();
            const interval = system.runInterval(() => {
                // Check if sneaking
                if (!player.isSneaking) {
                    timers.delete(player.id);
                    system.clearRun(interval);
                    tracker.clear();
                    return;
                }
                // Enable Warden Ability if Timer is greather than 3 seconds
                const time = timers.get(player.id);
                if (time > 2) {
                    if (time < 4) {
                        player.playSound("power.on.sculk_sensor");
                        player.addEffect("blindness", 60);
                    }
                    for (const target of dimension.getEntities({ location: player.location, maxDistance: 8 })) {
                        if (tracker.has(target) || target.id === player.id || blacklist.includes(target.typeId))
                            continue;
                        const glow = dimension.spawnEntity("pa:dummy_soul", target.location);
                        tracker.set(target, glow);
                    }
                    // Add entity and spawn glow entity
                }
                // Teleport entity
                for (const [target, glow] of tracker.entries()) {
                    if (!target.isValid() || !inAnyRadius(target, 8)) {
                        if (glow.isValid())
                            glow.remove();
                        tracker.delete(target);
                        continue;
                    }
                    glow.teleport(target.location);
                }
                timers.set(player.id, time + 1);
            }, 20);
        }
    },
    Chest: {
        lore: "§r§9+1 Fire Resistance",
        effect: {
            id: "fire_resistance",
            amplifier: 0,
            duration: 3
        }
    },
    Feet: {
        lore: "§r§9+1 Warden Transmutation",
        func: (player) => {
            const { location, dimension } = player;
            const block = dimension.getBlock(location);
            if (!block || !block.permutation.matches("minecraft:sculk_vein"))
                return;
            block.setPermutation(BlockPermutation.resolve("minecraft:air"));
            dimension.spawnEntity("minecraft:xp_orb", location);
        }
    },
    Legs: {
        lore: "§r§9+1 Knockback Resistance"
    }
};
